pro amsu_daily_product
;=====================================================================
;@***h*  MW_Sounder_FCDR/amsu_daily_product.pro
;
; NAME
;        amsu_daily_product.pro
;
; LOCATION
;        $SRC_DIR/Src_IDL/
;
; DESCRIPTION:
;
; EXTERNALS:
;              none.
;
; USAGE:
;              The RUN parameters specifying the data to process are set
;              directly below this header. The user needs to edit these
;              values to process the desired values and then execute the
;              program from within IDL.
;
; INPUTS:
;              Daily Christy calibrated data:
;                $InPath_prod/
;
;              Selected best guess number:
;                $InPath_coef/
;
; OUTPUTS:
;              Best results:
;                $OutPath/YYYYMM/YYYDDD_{noaa}_nc
;
; AUTHOR:
;              Liang Peng / Ben Ho (?)
;
; REVISIONS:
;              Liang Peng (Formatted for CDR)
;
;
; COPYRIGHT
;              © University Corporation for Atmospheric Research (UCAR) 2011.
;              All rights reserved. Please refer to the UCAR copyright
;              statement in the main directory
;
;@*****
;=====================================================================

;**************************************************************************
; Set RUN parameters here:
;      JD_BEG  = The Begining Julian day to process;julday(month,dayofmonth,year)
;      JD_END  = The Ending Julian day to process
; InPath_coef  = Path to coeffcients.
; InPath_prod  = Path to grid BT data
; OutPath      = Path to output data
;        noaa  = The polar orbiter to use
;
;              Path values should contain a trailing '/'
;**************************************************************************
JD_BEG      = julday( 1, 1,2001);
JD_END      = julday(12,31,2014)
InPath_coef = "../Data/tmp/sno/rebuild/coef/"
InPath_prod = "../Data/tmp/sno/rebuild/grid/"
OutPath     = "../Data/tmp/sno/rebuild/product/"
noaa        = 'noaa15'
;*********************************************************
; End of RUN parameters
;*********************************************************

;
; Read ID of guess number
; ---------------------------------------------------------------
restore,inpath_coef+'rebuild.sav'
snol = string(inol,format='(i2.2)')

;
; Set Julian days that will be dealwithed
;-----------------------------------------------------------------------
jds = timegen(start=JD_BEG,final=JD_END,unit='day')

;
; Loop over the Julian days to process
;----------------------------------
for ijd = 0,n_elements(jds)-1 do begin

  ;
  ; Set time variables
  ;----------------------------------
  jd = jds[ijd]
  caldat,jd,month,dom,year
  doy = jd-julday(1,0,year)
  adoy = doy*1.0/(julday(12,31,year)-julday(1,0,year))   
  syear  = string(year, f='(i4.4)')
  smonth = string(month,f='(i2.2)')
  sdoy   = string(doy,  f='(i3.3)')

 
  ;
  ; Set the infile
  ;---------------------------------- 
  Infile = file_search(Inpath_prod+syear+smonth+'/'+syear+sdoy+'_'+noaa+'_nol'+snol+'_nc')
  if ~file_test(Infile)  then goto,next_day
  print,Infile

  ;
  ; Set the output file
  ;----------------------------------
  outfile = Outpath+syear+smonth+'/'+syear+sdoy+'_'+noaa+'_nc'
  print,outfile

  ;
  ; Copy data file
  ;---------------------------------
  outdir = file_dirname(outfile)
  if ~file_test(outdir) then spawn,'mkdir -p '+outdir
  spawn,'cp '+infile+' '+outfile

  next_day:
endfor

stop
end
