pro msu_yrange,noaa,chan,yrange_count,yrange0,yrange1,coldrange
;=====================================================================
;@***h*  MW_Sounder_FCDR/msu_yrange.pro
;  
; NAME
;        msu_yrange.pro
;
; LOCATION
;        $SRC_DIR/Src_IDL/
;
; DESCRIPTION: 
;              Set criteria for bad raw scene count and Criteria for bad 
;              Calibration Coefficients 
;
;
; EXTERNALS:   
;              none.
;
; USAGE:       
;              The RUN parameters specifying the data to process are set 
;              directly below this header. The user needs to edit these 
;              values to process the desired values and then execute the 
;              program from within IDL.
;
; INPUTS:   
;              Mission name and channel ID
;
; OUTPUTS:      
;              Criteria for bad raw scene count and Criteria for bad 
;              Calibration Coefficients
;
; AUTHOR:      
;              Liang Peng / Xinjia Zhou / Ben Ho (?)
;
; REVISIONS:   
;              Liang Peng (Formatted for CDR)
;
;
; COPYRIGHT
;              © University Corporation for Atmospheric Research (UCAR) 2011.
;              All rights reserved. Please refer to the UCAR copyright 
;              statement in the main directory
;
;@*****
;=====================================================================

;
; Criteria for bad raw scene count
;-----------------------------------------
if noaa eq 'noaa14' then begin
  yrange_count = [2100, 2650]
endif else if noaa eq 'noaa12' then begin
  yrange_count= [2200 ,2800]
endif else if noaa eq 'noaa11' then begin
  yrange_count= [2150 , 2800]
endif else if noaa eq 'noaa10' then begin
  yrange_count= [2150 , 2700]
endif else if noaa eq 'noaa9' then begin
  yrange_count= [2100 , 2700]
endif else if noaa eq 'noaa8' then begin
  yrange_count= [2000 , 2600]
endif else if noaa eq 'noaa7' then begin
  yrange_count= [2100,2700]
endif else if noaa eq 'noaa6' then begin
  yrange_count= [2200,2800]
endif else if noaa eq 'tiros' then begin
  yrange_count= [2150,2800]
endif

;
; Criteria for bad Calibration Coefficients 
;-----------------------------------------
if noaa eq 'noaa14' then begin
  yrange0=[3990,4045]&yrange1=[-10100, -9300] ;noaa14
endif else if noaa eq 'noaa12' then begin
  yrange0=[4400,4700]&yrange1=[-20000,-15000] ;noaa12
endif else if noaa eq 'noaa11' then begin
  yrange0=[4100,4300]&yrange1=[-14000,-12000] ;noaa11
endif else if noaa eq 'noaa10' then begin
  yrange0=[4100,4160]&yrange1=[-12000,-11200] ;noaa10
endif else if noaa eq 'noaa9' then begin
  yrange0=[4090,4160]&yrange1=[-11500,-10700] ;noaa9
endif else if noaa eq 'noaa8' then begin
  yrange0=[3610,3660]&yrange1=[-5300,  -4700] ;noaa8
endif else if noaa eq 'noaa7' then begin
  yrange0=[4030,4090]&yrange1=[-11100,-10200] ;noaa7
endif else if noaa eq 'noaa6' then begin
  yrange0=[4000,4350]&yrange1=[-15000,-11000] ;noaa6
endif else if noaa eq 'tiros' then begin
  yrange0=[3960,4030]&yrange1=[-11000,-10000] ;tiros
endif

;
; Set cold count range
;-----------------------------------------
if chan eq 4 then coldrange = [200,1200]
if chan eq 3 then coldrange = [-1,1200]
end
