pro sno_step8_select_msu
;=====================================================================
;@***h*  MW_Sounder_FCDR/sno_step8_select_msu.pro
;
; NAME
;        sno_step8_select_msu.pro
;
; LOCATION
;        $SRC_DIR/Src_IDL/
;
; DESCRIPTION: 
;              For specified names of MSU pairs, this program read in the 
;              MSU intersatellite biases to calculate the RMS. The rebuilt 
;              ID of guess which show smallest RMS rebuilt BTs is written 
;              to an IDL data file for later use.
;
;
; EXTERNALS:   
;              none.
;
; USAGE:       
;              The RUN parameters specifying the data to process are set 
;              directly below this header. The user needs to edit these 
;              values to process the desired values and then execute the 
;              program from within IDL.
;
; INPUTS:      
;              Intersatellite bias data:
;                $InPath/
;
; OUTPUTS:     
;              Id for best rebuild data: 
;                $OutPath/
;
; AUTHOR:      
;              Liang Peng / Ben Ho (?)
;
; REVISIONS:   
;              Liang Peng (Formatted for CDR)
;
;
; COPYRIGHT
;              © University Corporation for Atmospheric Research (UCAR) 2011.
;              All rights reserved. Please refer to the UCAR copyright 
;              statement in the main directory
;
;@*****
;=====================================================================


;**************************************************************************
; Set RUN parameters here:
;       JD_BEG = The begining Julian day to process
;       JD_END = The ending Julian day to process
;      InPath  = Path to intersatellite bias
;     OutPath  = Path to output data
;
;              Path values should contain a trailing '/'
;**************************************************************************
Inpath = '../Data/tmp/sno/rebuild/new_bias/'
Outpath = '../Data/tmp/sno/rebuild/coef/'
JD_BEG = julday( 1, 1,1979)
JD_END = julday(12,31,2006)

;*********************************************************
; End of RUN parameters
;*********************************************************

;
; Set Julian days that will be dealwithed
;-----------------------------------------------------------------------
jds = timegen(start=JD_BEG,final=JD_END,unit='day')

;
; Set names of satellites
;-----------------------------------------------------------------------
noaas = ['noaa14-noaa12','noaa12-noaa11','noaa11-noaa10']

;
; Read in inter satellite bias
; ----------------------------------------------------------------------
bias_all = dblarr(6,n_elements(noaas),n_elements(jds),11)
for inol = 0,10 do begin
  for inoaa = 0,n_elements(noaas)-1 do begin
    snol = string(inol,format='(i2.2)')
    restore,Inpath+noaas[inoaa]+'_nol'+snol+'.sav'
    bias_all[*,inoaa,*,inol] = bias
  endfor
endfor

;
; Set inter bias
; ---------------------------------------------------------------------
rms_tt = fltarr(11)
for inol = 0,10 do begin

  ;
  ; Set root-mean-squre of inter bias
  ; --------------------------------------------------
  bias = bias_all[*,*,*,inol]
  rms = fltarr(n_elements(bias[0,*,0]))
  num = rms
  for ir = 0,n_elements(rms)-1 do begin
    dif = bias[0,ir,*]
    id = where(abs(dif) le 10)
    dif = dif[id]
    dif2 = dif^2
    rms[ir] = sqrt(mean(dif2))
    num[ir] = n_elements(id)
  endfor

  ;
  ; Set mean of root-mean-squre 
  ; --------------------------------------------------
  rms_tt[inol] = total(rms*num)/total(num)

  if inol eq 0 then begin
    rms_all = fltarr(n_elements(rms)+1,11)
  endif
  rms_all[0:n_elements(rms)-1,inol] = rms
  rms_all[n_elements(rms),inol] = rms_tt[inol]
endfor

;
; Save id of best rebuild data 
; -------------------------------------------------------------------
minvalue = min(rms_tt,id)
inol = id
save,filename=Outpath+'rebuild.sav',inol
print,inol

pro_end:
stop
end





