	subroutine transmsu42(temp,wvmr,theta,kan,taut,*)

C------------------------------------------------------------------------
c * Calculate MSU transmittances for TIROS-N/NOAA-6 through NOAA-14
c .... version of 22.12.05

c * Strow-Woolf regression model based on line-by-line transmittances.
c * Input temperatures and water-vapor mixing ratios must be defined at
c * the pressure levels in array 'pstd' (see block data 'stdatmos').
c * Units -- temp, deg-K; water vapor, g/kg.
c * Logical units 51 and 52 are used for coefficient files.
c * Component taus are returned through common, product in 'taut'.

	parameter (nkd=4,nkw=4,nl=42,nm=nl-1)
	parameter (nxd= 8,ncd=nxd+1)
	parameter (nxw=11,ncw=nxw+1)
	parameter (iud=51,iuw=52)
	common/stdatm/pstd(nl),tstd(nl),wstd(nl)
	common/taumdw/taud(nl),tauw(nl)
	dimension temp(*),wvmr(*),taut(*)
	dimension coefd(ncd,nm,nkd),cdry(ncd,nm),xdry(nxd,nm)
	dimension coefw(ncw,nm,nkw),cwet(ncw,nm),xwet(nxw,nm)
	dimension pavg(nm),tref(nm),wref(nm),tavg(nm),wamt(nm)
	dimension secp(nm),tlas(nl),wlas(nl)
	character*12 dfile/'tmsuzdry.asc'/
	character*12 wfile/'tmsuzwet.asc'/
	logical newang,newatm
	data zlas/-999./,tlas/nl*0./,wlas/nl*0./,init/1/
	secant(x)=1./cos(0.01745329*x)

c           write(*,*)'here1',init,coefd(1,1,1)
	!if(init.ne.0) then
	if(.true.) then
	   open(iud,file=dfile,form='formatted',status='old',
     +		err=200)
	   read(iud,'(5e14.8)') coefd
c           write(*,*)'coefd',coefd(1,1,1)
	   close(iud)
	   open(iuw,file=wfile,form='formatted',status='old',
     +     err=200)
	   read(iuw,'(5e14.8)') coefw
	   close(iuw)
	   call conpmw(pstd,tstd,wstd,nl,1,pavg,tref,wref)
	   init=0
	endif
c           write(*,*)'here2',coefd(8,41,2)

	dt=0.
	dw=0.
	do j=1,nl
	   dt=dt+abs(temp(j)-tlas(j))
	   tlas(j)=temp(j)
	   dw=dw+abs(wvmr(j)-wlas(j))
	   wlas(j)=wvmr(j)
	   taud(j)=1.0
	   tauw(j)=1.0
	   taut(j)=1.0
	enddo
	datm=dt+dw

	newatm=datm.ne.0.
	!if(newatm) then
	if(.true.) then
	   call conpmw(pstd,temp,wvmr,nl,1,pavg,tavg,wamt)
	endif

	newang=theta.ne.zlas
	!if(newang) then
	if(.true.) then
	   if(theta.eq.0.) then
	      secz=1.
	   else
	      secz=secant(theta)
	   endif
	   do j=1,nm
	      secp(j)=secz
	   enddo
	   zlas=theta
	endif

	!if(newang.or.newatm) then
	if(.true.) then
	   call calpmw(tref,wref,tavg,wamt,pavg,secp,
     +			nm,nxd,nxw,xdry,xwet)
	endif

c * dry
	do j=1,nm
	   do i=1,ncd
	      cdry(i,j)=coefd(i,j,kan)
	   enddo
	enddo
         
	call taucal(ncd,nxd,nm,cdry,xdry,taud)

c * wet
	do j=1,nm
	   do i=1,ncw
	      cwet(i,j)=coefw(i,j,kan)
	   enddo
	enddo
	call taucal(ncw,nxw,nm,cwet,xwet,tauw)
c        write(*,*)tauw

c * total
	do j=1,nl
	   taut(j)=taud(j)*tauw(j)
	enddo
	return

200	return1
	end

c * Subprograms for microwave transmittance
c	at 42-level SPACECRAFT pressure coordinate

c .... version of 11.10.04

Contents:

c	block data stdatmos
c	subroutine calpmw
c	subroutine conpmw
c	subroutine gphite
c	subroutine taucal

c ************************

	block data stdatmos
	parameter (nl=42)
c * Reference Atmosphere is 1976 U.S. Standard
	common/stdatm/pstd(nl),tstd(nl),wstd(nl)

      data pstd/ .1,.2,.5,1.,1.5,2.,3.,4.,5.,7.,10.,15.,20.,25.,30.,
     + 50.,60.,70.,85.,100.,115.,135.,150.,200.,250.,300.,350.,400.,
     + 430.,475.,500.,570.,620.,670.,700.,780.,850.,920.,950.,1000.,
     + 1025.,1050./

      data tstd/231.70, 245.22,
     +  263.35, 270.63, 264.07, 257.93, 249.51, 243.65, 239.24, 232.64,
     +  228.07, 225.00, 223.13, 221.72, 220.54, 217.28, 216.70, 216.70,
     +  216.70, 216.70, 216.70, 216.70, 216.70, 216.72, 220.85, 228.58,
     +  235.38, 241.45, 244.81, 249.48, 251.95, 258.32, 262.48, 266.40,
     +  268.61, 274.21, 278.74, 282.97, 284.71, 287.50, 288.84, 290.15/

      data wstd/ 0.003,  0.003,
     +   0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.003,  0.004,  0.005,  0.014,  0.036,  0.089,
     +   0.212,  0.331,  0.427,  0.588,  0.699,  1.059,  1.368,  1.752,
     +   1.969,  2.741,  3.366,  3.976,  4.255,  4.701,  4.916,  5.125/

	end
cccccccccc

C------------------------------------------------------------------------
      subroutine calpmw(t_avg_ref,  amt_wet_ref,
     +                        t_avg,      amt_wet,
     +                        p_avg,      sec_theta,   n_layers,
     +                        n_dry_pred, n_wet_pred,
     +                        pred_dry,   pred_wet)
c #### 41 layers!

c  PURPOSE:

c    Routine to calculate the predictors for the dry (temperature), 
c      and wet components of a fast transmittance model for a
c      scanning satellite based microwave instrument.

c  REFERENCES:

c    AIRS FTC package science notes and software, S. Hannon and L. Strow,
c      Uni. of Maryland, Baltimore County (UMBC)

c  CREATED:

c    19-Sep-1996 HMW

c  ARGUMENTS:

c      Input
c    -----------
c     t_avg_ref  - REAL*4 reference layer average temperature array (K)

c    amt_wet_ref - REAL*4 reference water vapour amount array (k.mol)/cm^2

c      t_avg     - REAL*4 layer average temperature array (K)

c     amt_wet    - REAL*4 water vapour amount array (k.mol)/cm^2

c      p_avg     - REAL*4 layer average pressure array (mb)

c    sec_theta   - REAL*4 secant of the zenith angle array

c     n_layers   - INT*4 Number of atmospheric layers

c    n_dry_pred  - INT*4 number of dry (temperature) predictors

c    n_wet_pred  - INT*4 number of water vapour predictors

c      Output
c    -----------
c     pred_dry   - REAL*4 dry gas (temperature) predictor matrix

c     pred_wet   - REAL*4 water vapour predictor matrix

c  COMMENTS:

c    Levels or Layers?
c    -----------------
c      Profile data is input at a number of *LAYERS*.

c    Layer Numbering pt. A
c    ---------------------
c      Layer 1   => Atmosphere between LEVELs 1 & 2
c      Layer 2   => Atmosphere between LEVELs 2 & 3
c                        .
c                        .
c                        .
c      Layer L-1 => Atmosphere between LEVELs L-1 & L

c    Layer Numbering pt. B
c    ---------------------
c      For the HIS instrument, Layer 1 is at the top of the atmosphere
c        and Layer L-1 is at the surface.    

c    Layer Numbering pt. C
c    ---------------------
c      In this routine the number of *LAYERS* is passed in the argument
c        list, _not_ the number of LEVELS.  This was done to improve
c        the readability of this code, i.e. loop from 1->L(ayers) 
c        rather than from 1->L(evels)-1.

c=======================================================================


c-----------------------------------------------------------------------
c                 Turn off implicit type declaration
c-----------------------------------------------------------------------

       implicit none

c------------------------------------------------------------------------
c                             Arguments
c------------------------------------------------------------------------

c -- Input

      integer*4 n_layers,
     +          n_dry_pred, n_wet_pred

      real*4    t_avg_ref(*), amt_wet_ref(*),
     +          t_avg(*),     amt_wet(*),
     +          p_avg(*),     sec_theta(*)

c -- Output

      real*4    pred_dry(n_dry_pred, *),
     +          pred_wet(n_wet_pred, *)


c------------------------------------------------------------------------
c                           Local variables
c------------------------------------------------------------------------

c -- Parameters

      integer*4 max_layers
      parameter ( max_layers = 41 )

      integer*4 max_dry_pred, max_wet_pred
      parameter ( max_dry_pred = 8,
     +            max_wet_pred = 11)

c -- Scalars

      integer*4 l

c -- Arrays

c     ....Pressure
      real*4    p_dp(max_layers),
     +          p_norm(max_layers)

c     ....Temperature
      real*4    delta_t(max_layers),
     +          t_ratio(max_layers),
     +          pw_t_ratio(max_layers)      ! Pressure weighted

c     ....Water vapour
      real*4    wet_ratio(max_layers),
     +          pw_wet(max_layers),         ! Pressure weighted
     +          pw_wet_ref(max_layers),     ! Pressure weighted
     +          pw_wet_ratio(max_layers)    ! Pressure weighted


c************************************************************************
c                         ** Executable code **
c************************************************************************

c------------------------------------------------------------------------
c                   -- Check that n_layers is o.k. --
c------------------------------------------------------------------------

      if( n_layers .gt. max_layers )then
        write(*,'(/10x,''*** calpmw : n_layers > max_layers'')')
        stop
      end if 

c------------------------------------------------------------------------
c         -- Check that numbers of predictors is consistent --
c------------------------------------------------------------------------

c     ---------------------------------
c     # of dry (temperature) predictors
c     ---------------------------------

      if( n_dry_pred .ne. max_dry_pred )then
        write(*,'(/10x,''*** calpmw : invalid n_dry_pred'')')
        stop
      end if 

c     ----------------------------
c     # of water vapour predictors
c     ----------------------------

      if( n_wet_pred .ne. max_wet_pred )then
        write(*,'(/10x,''*** calpmw : invalid n_wet_pred'')')
        stop
      end if 

c------------------------------------------------------------------------
c         -- Calculate ratios, offsets, etc, for top layer --
c------------------------------------------------------------------------

c     ------------------
c     Pressure variables
c     ------------------

      p_dp(1)   = p_avg(1) * ( p_avg(2) - p_avg(1) )
      p_norm(1) = 0.0

c     ---------------------
c     Temperature variables
c     ---------------------

      delta_t(1)    = t_avg(1) - t_avg_ref(1)
      t_ratio(1)    = t_avg(1) / t_avg_ref(1)
      pw_t_ratio(1) = 0.0

c     ----------------
c     Amount variables
c     ----------------

c     ....Water vapour
 
      wet_ratio(1)    = amt_wet(1) / amt_wet_ref(1)
      pw_wet(1)       = p_dp(1) * amt_wet(1)
      pw_wet_ref(1)   = p_dp(1) * amt_wet_ref(1)
      pw_wet_ratio(1) = wet_ratio(1)

c------------------------------------------------------------------------
c         -- Calculate ratios, offsets, etc, for all layers --
c------------------------------------------------------------------------

      do l = 2, n_layers

c       ------------------
c       Pressure variables
c       ------------------

        p_dp(l) = p_avg(l) * ( p_avg(l) - p_avg(l-1) )
        p_norm(l) = p_norm(l-1) + p_dp(l)

c       ---------------------
c       Temperature variables
c       ---------------------

        delta_t(l)    = t_avg(l) - t_avg_ref(l)
        t_ratio(l)    = t_avg(l) / t_avg_ref(l)
        pw_t_ratio(l) = pw_t_ratio(l-1) + ( p_dp(l) * t_ratio(l-1) )

c       ----------------
c       Amount variables
c       ----------------

c       ..Water vapour

        wet_ratio(l)  = amt_wet(l) / amt_wet_ref(l)
        pw_wet(l)     = pw_wet(l-1) + ( p_dp(l) * amt_wet(l) )
        pw_wet_ref(l) = pw_wet_ref(l-1) + ( p_dp(l) * amt_wet_ref(l) )

      end do

c------------------------------------------------------------------------
c              -- Scale the pressure dependent variables --
c------------------------------------------------------------------------

      do l = 2, n_layers

        pw_t_ratio(l)   = pw_t_ratio(l) / p_norm(l)
        pw_wet_ratio(l) = pw_wet(l) / pw_wet_ref(l)
 
      end do

c------------------------------------------------------------------------
c                     -- Load up predictor arrays --
c------------------------------------------------------------------------

      do l = 1, n_layers

c       ----------------------
c       Temperature predictors
c       ----------------------

        pred_dry(1,l) = sec_theta(l)
        pred_dry(2,l) = sec_theta(l) * sec_theta(l)
        pred_dry(3,l) = sec_theta(l) * t_ratio(l)
        pred_dry(4,l) = pred_dry(3,l) * t_ratio(l)
        pred_dry(5,l) = t_ratio(l)
        pred_dry(6,l) = t_ratio(l) * t_ratio(l)
        pred_dry(7,l) = sec_theta(l) * pw_t_ratio(l)
        pred_dry(8,l) = pred_dry(7,l) / t_ratio(l) 

c       -----------------------
c       Water vapour predictors
c       -----------------------

        pred_wet(1,l)  = sec_theta(l) * wet_ratio(l)
        pred_wet(2,l)  = sqrt( pred_wet(1,l) )
        pred_wet(3,l)  = pred_wet(1,l) * delta_t(l)
        pred_wet(4,l)  = pred_wet(1,l) * pred_wet(1,l)
        pred_wet(5,l)  = abs( delta_t(l) ) * delta_t(l) * pred_wet(1,l)
        pred_wet(6,l)  = pred_wet(1,l) * pred_wet(4,l)
        pred_wet(7,l)  = sec_theta(l) * pw_wet_ratio(l)
        pred_wet(8,l)  = pred_wet(2,l) * delta_t(l)
        pred_wet(9,l)  = sqrt( pred_wet(2,l) )
        pred_wet(10,l) = pred_wet(7,l) * pred_wet(7,l)
        pred_wet(11,l) = sqrt( pred_wet(7,l) )

      end do
         
      return
      end
cccccccccc

C------------------------------------------------------------------------
      subroutine conpmw( p, t, w, n_levels, i_dir,
     +                         p_avg, t_avg, w_amt)

c  PURPOSE:

c    Function to convert atmospheric water vapour (g/kg) profile
c      specified at n_levels layer BOUNDARIES to n_levels-1
c      integrated layer amounts of units (k.moles)/cm^2 for use in
c	 microwave fast transmittance models. The average LAYER
c      pressure and temperature are also returned.

c  REFERENCES:

c    AIRS LAYERS package science notes, S. Hannon and L. Strow, Uni. of
c      Maryland, Baltimore County (UMBC)

c  CREATED:

c    19-Sep-1996 HMW

c  ARGUMENTS:

c     Input
c    --------
c       p     - REAL*4 pressure array (mb)

c       t     - REAL*4 temperature profile array (K)

c       w     - REAL*4 water vapour profile array (g/kg)

c    n_levels - INT*4 number of elements used in passed arrays

c     i_dir   - INT*4 direction of increasing layer number

c                 i_dir = +1, Level(1) == p(top)         } satellite/AC
c                             Level(n_levels) == p(sfc)  }    case

c                 i_dir = -1, Level(1) == p(sfc)         } ground-based
c                             Level(n_levels) == p(top)  }    case

c     Output
c    --------
c     p_avg   - REAL*4 average LAYER pressure array (mb)

c     t_avg   - REAL*4 average LAYER temperature (K)

c     w_amt   - REAL*4 integrated LAYER water vapour amount array (k.moles)/cm^2

c  ROUTINES:

c    Subroutines:
c    ------------
c      gphite      - calculates geopotential height given profile data.

c    Functions:
c    ----------
c      NONE

c  COMMENTS:

c    Levels or Layers?
c    -----------------
c      Profile data is input at a number of *LEVELS*.  Number densitites
c        are calculated for *LAYERS* that are bounded by these levels.
c        So, for L levels there are L-1 layers.

c    Layer Numbering
c    ---------------
c      Layer 1   => Atmosphere between LEVELs 1 & 2
c      Layer 2   => Atmosphere between LEVELs 2 & 3
c                        .
c                        .
c                        .
c      Layer L-1 => Atmosphere between LEVELs L-1 & L

c=======================================================================

c-----------------------------------------------------------------------
c              -- Prevent implicit typing of variables --
c-----------------------------------------------------------------------

      implicit none

c-----------------------------------------------------------------------
c                           -- Arguments --
c-----------------------------------------------------------------------

c -- Arrays

      real*4    p(*), t(*), w(*),
     +          p_avg(*), t_avg(*), w_amt(*)

c -- Scalars

      integer*4 n_levels, i_dir

c-----------------------------------------------------------------------
c                         -- Local variables --
c-----------------------------------------------------------------------

c -- Parameters

      integer*4 max_levels
      parameter ( max_levels = 42 )         ! Maximum number of levels

      real*4    r_equator, r_polar, r_avg
      parameter ( r_equator = 6.378388e+06, ! Earth radius at equator
     +            r_polar   = 6.356911e+06, ! Earth radius at pole
     +            r_avg     = 0.5*(r_equator+r_polar) )

      real*4    g_sfc
      parameter ( g_sfc = 9.80665 )         ! Gravity at surface

      real*4    rho_ref
      parameter ( rho_ref = 1.2027e-12 )    ! Reference air "density"

      real*4    mw_dryair, mw_h2o
      parameter ( mw_dryair = 28.97,        ! Molec. wgt. of dry air (g/mol)
     +            mw_h2o    = 18.0152)      ! Molec. wgt. of water

      real*4    R_gas, R_air
      parameter ( R_gas = 8.3143,           ! Ideal gas constant (J/mole/K)
     +            R_air = 0.9975*R_gas )    ! Gas constant for air (worst case) 

c -- Scalars

      integer*4 l, l_start, l_end, l_indx

      real*4    rho1, rho2, p1, p2, w1, w2, z1, z2,
     +          c_avg, g_avg, z_avg, w_avg,
     +          dz, dp, r_hgt, wg, A, B

c -- Arrays

      real*4    z(max_levels),              ! Pressure heights (m)
     +          g(max_levels),              ! Acc. due to gravity (m/s/s)
     +          mw_air(max_levels),         ! Molec. wgt. of air (g/mol)
     +          rho_air(max_levels),        ! air mass density (kg.mol)/m^3
     +          c(max_levels),              ! (kg.mol.K)/(N.m)
     +          w_ppmv(max_levels)          ! h2o LEVEL amount (ppmv)

c***********************************************************************
c                         ** Executable code **
c***********************************************************************

c-----------------------------------------------------------------------
c           -- Calculate initial values of pressure heights --
c-----------------------------------------------------------------------

      call gphite( p, t, w, 0.0, n_levels, i_dir, z)

c-----------------------------------------------------------------------
c      -- Set loop bounds for direction sensitive calculations --
c      -- so loop iterates from surface to the top             --
c-----------------------------------------------------------------------

      if( i_dir .gt. 0 )then

c       --------------------
c       Data stored top down
c       --------------------

        l_start = n_levels
        l_end   = 1

      else

c       ---------------------
c       Data stored bottom up
c       ---------------------

        l_start = 1
        l_end   = n_levels

      end if

c-----------------------------------------------------------------------
c          -- Air molecular mass and density, and gravity --
c          -- as a function of LEVEL                      --
c-----------------------------------------------------------------------

c     -----------------------
c     Loop from bottom to top
c     -----------------------

      do l = l_start, l_end, -1*i_dir

c       ---------------------------------
c       Convert water vapour g/kg -> ppmv
c       ---------------------------------

        w_ppmv(l) = 1.0e+03 * w(l) * mw_dryair / mw_h2o

c       -----------------------------------------
c       Calculate molecular weight of air (g/mol)
c       ----------------------------------------

        mw_air(l) = ( ( 1.0 - (w_ppmv(l)/1.0e+6) ) * mw_dryair ) +
     +              ( ( w_ppmv(l)/1.0e+06 ) * mw_h2o )

c       ----------------
c       Air mass density
c       ----------------

        c(l) = 0.001 * mw_air(l) / R_air    ! 0.001 factor for g -> kg
        rho_air(l) = c(l) * p(l) / t(l)

c       -------
c       Gravity
c       -------

        r_hgt = r_avg + z(l)                !  m
        g(l) = g_sfc -                      !  m/s^2
     +         g_sfc*( 1.0 - ( (r_avg*r_avg)/(r_hgt*r_hgt) ) )

      end do
 
c-----------------------------------------------------------------------
c                        -- LAYER quantities --
c-----------------------------------------------------------------------

c     -----------------------
c     Loop from bottom to top
c     -----------------------

      do l = l_start, l_end+i_dir, -1*i_dir

c       -------------------------------------------------------
c       Determine output array index.  This is done so that the
c       output data is always ordered from 1 -> L-1 regardless
c       of the orientation of the input data.  This is true by
c       default only for the bottom-up case.  For the top down
c       case no correction would give output layers from 2 -> L
c       -------------------------------------------------------

        if( i_dir .gt. 0 )then

          l_indx = l - 1

        else

          l_indx = l

        end if

c       ---------------------------------------
c       Assign current layer boundary densities
c       ---------------------------------------
 
        rho1 = rho_air(l)
        rho2 = rho_air(l-i_dir)
 
c       ---------
c       Average c
c       ---------

        c_avg = ( (rho1*c(l)) + (rho2*c(l-i_dir)) ) / ( rho1 + rho2 )

c       ---------
c       Average t
c       ---------

        t_avg(l_indx) = 
     +          ( (rho1*t(l)) + (rho2*t(l-i_dir)) ) / ( rho1 + rho2 )

c       ---------
c       Average p
c       ---------

        p1 = p(l)
        p2 = p(l-i_dir)

        z1 = z(l)
        z2 = z(l-i_dir)

        dp = p2 - p1

        A = log(p2/p1) / (z2-z1)
        B = p1 / exp(A*z1)

        p_avg(l_indx) = dp / log(p2/p1)

c       ------------------------------------------------
c       LAYER thickness (rather long-winded as it is not
c       assumed the layers are thin) in m. Includes
c       correction for altitude/gravity.
c       ------------------------------------------------

c       ...Initial values
        g_avg = g(l)
        dz = -1.0 * dp * t_avg(l_indx) / ( g_avg*c_avg*p_avg(l_indx) )

c       ...Calculate z_avg
        z_avg = z(l) + ( 0.5*dz )

c       ...Calculate new g_avg
        r_hgt = r_avg + z_avg 
        g_avg = g_sfc - g_sfc*( 1.0 - ( (r_avg*r_avg)/(r_hgt*r_hgt) ) )

c       ...Calculate new dz
        dz = -1.0 * dp * t_avg(l_indx) / ( g_avg*c_avg*p_avg(l_indx) )

c       ----------------------------------------
c       Calculate LAYER amounts for water vapour
c       ----------------------------------------

        w1 = w_ppmv(l)
        w2 = w_ppmv(l-i_dir)

        w_avg =  ( (rho1*w1) + (rho2*w2) ) / ( rho1+rho2 )

        w_amt(l_indx) =
     +       rho_ref * w_avg * dz * p_avg(l_indx) / t_avg(l_indx)

      end do

      return
      end
cccccccccc
C------------------------------------------------------------------------
      subroutine gphite( p, t, w, z_sfc, n_levels, i_dir, z)

c PURPOSE:

c  Routine to compute geopotential height given the atmospheric state.
c    Includes virtual temperature adjustment.

c CREATED:

c  19-Sep-1996 Received from Hal Woolf, recoded by Paul van Delst
c  18-May-2000 Logic error related to z_sfc corrected by Hal Woolf

c  ARGUMENTS:

c     Input
c    --------
c       p     - REAL*4 pressure array (mb)

c       t     - REAL*4 temperature profile array (K)

c       w     - REAL*4 water vapour profile array (g/kg)

c     z_sfc   - REAL*4 surface height (m).  0.0 if not known.

c    n_levels - INT*4 number of elements used in passed arrays

c     i_dir   - INT*4 direction of increasing layer number

c                 i_dir = +1, Level(1) == p(top)         } satellite/AC
c                             Level(n_levels) == p(sfc)  }    case

c                 i_dir = -1, Level(1) == p(sfc)         } ground-based
c                             Level(n_levels) == p(top)  }    case

c     Output
c    --------
c       z     - REAL*4 pressure level height array (m)

c COMMENTS:

c   Dimension of height array may not not be the same as that of the
c     input profile data.

c=======================================================================

c-----------------------------------------------------------------------
c              -- Prevent implicit typing of variables --
c-----------------------------------------------------------------------

      implicit none

c-----------------------------------------------------------------------
c                           -- Arguments --
c-----------------------------------------------------------------------

c -- Arrays

      real*4    p(*), t(*), w(*), 
     +          z(*)

c -- Scalars

      integer*4 n_levels, i_dir

      real*4    z_sfc

c-----------------------------------------------------------------------
c                         -- Local variables --
c-----------------------------------------------------------------------

c -- Parameters

      real*4    rog, fac
      parameter ( rog = 29.2898, 
     +            fac = 0.5 * rog )

c -- Scalars

      integer*4 i_start, i_end, l

      real*4    v_lower, v_upper, algp_lower, algp_upper, hgt

c***********************************************************************
c                         ** Executable code **
c***********************************************************************

c-----------------------------------------------------------------------
c  -- Calculate virtual temperature adjustment and exponential       --
c  -- pressure height for level above surface.  Also set integration --
c  -- loop bounds                                                    --
c-----------------------------------------------------------------------

      if( i_dir .gt. 0 )then

c       --------------------
c       Data stored top down
c       --------------------

        v_lower = t(n_levels) * ( 1.0 + ( 0.00061 * w(n_levels) ) )

        algp_lower = alog( p(n_levels) )

        i_start = n_levels-1
        i_end   = 1

      else

c       ---------------------
c       Data stored bottom up
c       ---------------------

        v_lower = t(1) * ( 1.0 + ( 0.00061 * w(1) ) )

        algp_lower = alog( p(1) )

        i_start = 2
        i_end   = n_levels

      end if

c-----------------------------------------------------------------------
c                     -- Assign surface height --
c-----------------------------------------------------------------------

      hgt = z_sfc

c .. Following added 18 May 2000 ... previously, z(n_levels) for downward
c       (usual) case was not defined!

      if(i_dir.gt.0) then
         z(n_levels) = z_sfc
      else
         z(1) = z_sfc
      endif

c .. End of addition

c-----------------------------------------------------------------------
c             -- Loop over layers always from sfc -> top --
c-----------------------------------------------------------------------

      do l = i_start, i_end, -1*i_dir

c       ----------------------------------------------------
c       Apply virtual temperature adjustment for upper level
c       ----------------------------------------------------

        v_upper = t(l)
        if( p(l) .ge. 300.0 )
     +    v_upper = v_upper * ( 1.0 + ( 0.00061 * w(l) ) )

c       ----------------------------------------------------- 
c       Calculate exponential pressure height for upper layer
c       ----------------------------------------------------- 

        algp_upper = alog( p(l) )

c       ----------------
c       Calculate height
c       ----------------

        hgt = hgt + ( fac*(v_upper+v_lower)*(algp_lower-algp_upper) )

c       -------------------------------
c       Overwrite values for next layer
c       -------------------------------

        v_lower = v_upper
        algp_lower = algp_upper

c       ---------------------------------------------
c       Store heights in same direction as other data
c       ---------------------------------------------

        z(l) = hgt

      end do

      return
      end
cccccccccc

C------------------------------------------------------------------------
	subroutine taucal(nc,nx,ny,cc,xx,tau)
c * General transmittance calculation ... Strow-Woolf model
	dimension cc(nc,ny),xx(nx,ny),tau(*)
	data trap/-999.99/

	last=ny
	taulyr=1.
	taulev=1.
	tau(1)=taulev
	do 110 j=1,ny
	if(taulev.eq.0.) go to 110
	if(j.gt.last) go to 100
	yy=cc(nc,j)
	if(yy.eq.trap) then
	   last=j
	   go to 100
	endif
	do i=1,nx
	   yy=yy+cc(i,j)*xx(i,j)
	enddo
	yy=amax1(yy,0.)
	if(yy.gt.0.) taulyr=exp(-yy)
100	taulev=taulev*taulyr
110	tau(j+1)=taulev
	return
	end

C-----------------------------------------------------------------------
C ... INTPUPT.FOR, 18 AUG 93, HMW/HBH ...
c  $DEBUG
      subroutine intupt(pi,ti,ni,pf,tf,nf)
c * for uplooking data
      dimension pi(*),ti(*),pf(*),tf(*)
      ij=1
      ii=1
      do 160 i=1,nf
      do 140 j=ij,ni
      jm1=j-1
      if(jm1.lt.1) jm1=1
      if(abs(pi(j)-pf(i)).le..001) go to 110
      if(pi(j)-pf(i)) 120,110,140
  110 tf(i)=ti(j)
      go to 150
  120 if(j.eq.ij) go to 130
      dlpi=alog(pi(j)/pi(jm1))
c      dlpi=(pi(j)/pi(jm1))
      slopt=(ti(j)-ti(jm1))/dlpi
      ii=j
  130 continue
      dlpf=alog(pf(i)/pi(jm1))
c      dlpf=(pf(i)/pi(jm1))
      tf(i)=ti(jm1)+slopt*dlpf
      go to 150
  140 continue
C ... 18 AUG 93, (BenH) .........
      IF(I.EQ.NF)TF(I)=TF(I-1)
C ...............................
  150 ij=ii
  160 continue
      return
      end


        subroutine intrte_mws(tran,temp,tsfc,esfc,lsfc, tbbd,tbbr,tbbs,tbbt)
C------------------------------------------------------------------------
c * Integrate RTE for a microwave sounder with surface reflection
c .... version of 28.10.04

c * Inputs:
c               tran = profile of transmittance (~1.0 at top)
c               temp = profile of temperature   (deg K)
c               tsfc = surface temperature      (deg K)
c               esfc = surface emissivity       (0.0 --> 1.0)
c               lsfc = surface level number     (101 = bottom [1100mb])
c * Outputs:
c               tbbd = direct (upwelling) component
c               tbbr = reflected component
c               tbbs = surface component
c               tbbt = total brightness temperature

        dimension tran(*),temp(*)

        n=lsfc
        taus=tran(n)
        m=n-1

c * accumulators for direct, reflected, and surface components
        tbbd=temp(1)*(tran(1)-tran(2))
        tbbr=0.0
        tbbs=0.0 

        do 100 l=2,m
        lm1=l-1
        taum=tran(lm1)
        lp1=l+1
        taup=tran(lp1)
        tt=temp(l)
        tbbd=tbbd+tt*(taum-taup)
        if(taus.eq.0.0) go to 100
        if(taum.eq.0.0) go to 100
        if(taup.eq.0.0) go to 100
        if(esfc.eq.1.0) go to 100
        tbbr=tbbr+tt*(taus/taup-taus/taum)
100     continue
        tt=temp(n)
        taum=tran(m)
        tbbd=tbbd+tt*(taum-taus)
        tbbd=0.5*tbbd

        if(taus.eq.0.0) then
c * no reflected or surface component
           tbbt=tbbd
           return
        endif

        tbbs=esfc*tsfc*taus
        if(taum.eq.0.0.or.esfc.eq.1.0) then
c * no reflected component
           tbbt=tbbd+tbbs
           return
        endif

c * finalize reflected component
        tbbr=tbbr+temp(1)*(taus/tran(2)-taus/tran(1))+tt*(1.-taus/taum)
c ... assume reflectivity = 1 - emissivity
        tbbr=0.5*tbbr*taus*(1.0-esfc)

        tbbt=tbbd+tbbr+tbbs
c        if(tbbt .eq. 0.) then
c            write(*,*)'tran:',tran(1)
c            write(*,*)'temp:',temp(1)
c            write(*,*)'tsfc:',tsfc
c            write(*,*)'esfc:',esfc
c            write(*,*)'lsfc:',lsfc
c            stop
c        endif
        return
        end


