        subroutine intrte_mws(tran,temp,tsfc,esfc,lsfc,
     &                         tbbd,tbbr,tbbs,tbbt)
        !@***s*  MW_Sounder_FCDR/aqua_amsu_tran
        !
        ! PURPOSE
        ! * Integrate RTE for a microwave sounder with surface reflection
        ! .... version of 28.10.04
        !
        ! INPUT:
        !        tran = profile of transmittance (~1.0 at top)
        !        temp = profile of temperature   (deg K)
        !        tsfc = surface temperature      (deg K)
        !        esfc = surface emissivity       (0.0 --> 1.0)
        !        lsfc = surface level number     (101 = bottom [1100mb])
 
        ! OUTPUT:
        !        tbbd = direct (upwelling) component
        !        tbbr = reflected component
        !        tbbs = surface component
        !        tbbt = total brightness temperature
        !@*****
        !=================================================================
 
        dimension tran(*),temp(*)

        n=lsfc
        taus=tran(n)
        m=n-1

        ! * accumulators for direct, reflected, and surface components
        tbbd=temp(1)*(tran(1)-tran(2))
        tbbr=0.0
        tbbs=0.0

        do 100 l=2,m
        lm1=l-1
        taum=tran(lm1)
        lp1=l+1
        taup=tran(lp1)
        tt=temp(l)
        tbbd=tbbd+tt*(taum-taup)
        if(taus.eq.0.0) go to 100
        if(taum.eq.0.0) go to 100
        if(taup.eq.0.0) go to 100
        if(esfc.eq.1.0) go to 100
        tbbr=tbbr+tt*(taus/taup-taus/taum)
100     continue
        tt=temp(n)
        taum=tran(m)
        tbbd=tbbd+tt*(taum-taus)
        tbbd=0.5*tbbd

        if(taus.eq.0.0) then
        ! * no reflected or surface component
           tbbt=tbbd
           return
        endif

        tbbs=esfc*tsfc*taus
        if(taum.eq.0.0.or.esfc.eq.1.0) then
        ! * no reflected component
           tbbt=tbbd+tbbs
           return
        endif

        ! * finalize reflected component
        tbbr=tbbr+temp(1)*(taus/tran(2)-taus/tran(1))+tt*(1.-taus/taum)
        ! ... assume reflectivity = 1 - emissivity
        tbbr=0.5*tbbr*taus*(1.0-esfc)

        tbbt=tbbd+tbbr+tbbs
        return
        end
